@@ -1,6 +1,7 @@
 /*
  * <one line to give the library's name and an idea of what it does.>
  * Copyright (C) 2014  Vishesh Handa <me@vhanda.in>
+ * Copyright (C) 2016  Christoph Cullmann <cullmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,24 +33,24 @@ using namespace KFileMetaData;
 
 QString OdfExtractorTest::testFilePath(const QString& fileName) const
 {
-    return QLatin1String(INDEXER_TESTS_SAMPLE_FILES_PATH) + QDir::separator() + fileName;
+    return QLatin1String(INDEXER_TESTS_SAMPLE_FILES_PATH) + QLatin1Char('/') + fileName;
 }
 
 void OdfExtractorTest::testText()
 {
-    QScopedPointer<ExtractorPlugin> plugin(new OdfExtractor(this));
+    OdfExtractor plugin{this};
 
-    SimpleExtractionResult result(testFilePath("test.odt"), "application/vnd.oasis.opendocument.text");
-    plugin->extract(&result);
+    SimpleExtractionResult result(testFilePath(QStringLiteral("test.odt")), QStringLiteral("application/vnd.oasis.opendocument.text"));
+    plugin.extract(&result);
 
     QCOMPARE(result.types().size(), 1);
-    QCOMPARE(result.types().first(), Type::Document);
+    QCOMPARE(result.types().at(0), Type::Document);
 
     QCOMPARE(result.properties().value(Property::Title), QVariant(QStringLiteral("KFileMetaData Title")));
     QCOMPARE(result.properties().value(Property::Subject), QVariant(QStringLiteral("KFileMetaData Subject")));
     QCOMPARE(result.properties().value(Property::Keywords), QVariant(QStringLiteral("KFileMetaData keyword")));
-    QCOMPARE(result.properties().value(Property::Comment), QVariant(QStringLiteral("KFileMetaData comment")));
-    QVERIFY(result.properties().value(Property::Generator).toString().contains("LibreOffice"));
+    QCOMPARE(result.properties().value(Property::Description), QVariant(QStringLiteral("KFileMetaData description")));
+    QVERIFY(result.properties().value(Property::Generator).toString().contains(QStringLiteral("LibreOffice")));
 
     QDateTime dt(QDate(2014, 07, 01), QTime(17, 37, 40, 690));
     QCOMPARE(result.properties().value(Property::CreationDate), QVariant(dt));
@@ -62,10 +63,10 @@ void OdfExtractorTest::testText()
 
 void OdfExtractorTest::testTextMetaDataOnly()
 {
-    QScopedPointer<ExtractorPlugin> plugin(new OdfExtractor(this));
+    OdfExtractor plugin{this};
 
-    SimpleExtractionResult result(testFilePath("test.odt"), "application/vnd.oasis.opendocument.text", ExtractionResult::ExtractMetaData);
-    plugin->extract(&result);
+    SimpleExtractionResult result(testFilePath(QStringLiteral("test.odt")), QStringLiteral("application/vnd.oasis.opendocument.text"), ExtractionResult::ExtractMetaData);
+    plugin.extract(&result);
 
     QCOMPARE(result.types().size(), 1);
     QCOMPARE(result.properties().size(), 8);
@@ -74,21 +75,36 @@ void OdfExtractorTest::testTextMetaDataOnly()
 
 void OdfExtractorTest::testPresentation()
 {
-    QScopedPointer<ExtractorPlugin> plugin(new OdfExtractor(this));
+    OdfExtractor plugin{this};
 
-    SimpleExtractionResult result(testFilePath("test.odp"), "application/vnd.oasis.opendocument.presentation");
-    plugin->extract(&result);
+    SimpleExtractionResult result(testFilePath(QStringLiteral("test.odp")), QStringLiteral("application/vnd.oasis.opendocument.presentation"));
+    plugin.extract(&result);
 
     QCOMPARE(result.types().size(), 2);
-    QCOMPARE(result.types()[0], Type::Document);
-    QCOMPARE(result.types()[1], Type::Presentation);
+    QCOMPARE(result.types().at(0), Type::Document);
+    QCOMPARE(result.types().at(1), Type::Presentation);
 
-    QVERIFY(result.properties().value(Property::Generator).toString().contains("LibreOffice"));
+    QVERIFY(result.properties().value(Property::Generator).toString().contains(QStringLiteral("LibreOffice")));
     QDateTime dt(QDate(2014, 07, 02), QTime(10, 59, 23, 434));
     QCOMPARE(result.properties().value(Property::CreationDate), QVariant(dt));
 
     QCOMPARE(result.text(), QStringLiteral("KFileMetaData Pres "));
 }
 
+void OdfExtractorTest::testTextMissingMetaNoCrash()
+{
+    OdfExtractor plugin{this};
 
-QTEST_MAIN(OdfExtractorTest)
+    SimpleExtractionResult result(testFilePath(QStringLiteral("test_missing_meta.odt")), QStringLiteral("application/vnd.oasis.opendocument.text"));
+    plugin.extract(&result);
+}
+
+void OdfExtractorTest::testTextMissingContentNoCrash()
+{
+    OdfExtractor plugin{this};
+
+    SimpleExtractionResult result(testFilePath(QStringLiteral("test_missing_content.odt")), QStringLiteral("application/vnd.oasis.opendocument.text"));
+    plugin.extract(&result);
+}
+
+QTEST_GUILESS_MAIN(OdfExtractorTest)
